package de.fhw.komponentenarchitekturen.knauf.jsf;


import java.io.Serializable;
import java.util.Vector;

/**
 * @author Wolfgang Knauf
 * This class holds a list of all side length values of the current
 * session.
 * 
 * Should implement @see="java.io.Serializable" because it is session data!
 */
public class History implements Serializable
{
  /**Serial version ID is required to avoid an Eclipse warning
   * 
   */
  private static final long serialVersionUID = 1L;
  
  /**This vector contains all side length inputs in the current session.
   */
  private Vector<SideLengths> vectorSideLengths = new Vector<SideLengths>();
  
  
  /**Add a new set of side lengths to the history
   * 
   * @param seitenlaengeAktuell Add this side lengths to the history
   * (not null)
   */
  public void addSideLength (SideLengths sideLengthCurrent)
  {
  	this.vectorSideLengths.add( sideLengthCurrent);
  }
 
  /**Copy the list to an array. 
   * Returning the list seems to be a problem for the WebTools JSF validator,
   * which does not seem to be able to detect the generic type of the return
   * value. 
   * At runtime, returning a vector worked for me, but I don't like seein Eclipse warnings ;-)
   * 
   * public Vector<SideLengths> getSideLengths()
   * 
   * @return Array of all side lengths.
   */
  public SideLengths[] getSideLengths()
  {
    SideLengths[] allSideLengths = new SideLengths[this.vectorSideLengths.size()];
    for (int intIndex = 0; intIndex < this.vectorSideLengths.size(); intIndex++)
    {
      allSideLengths[intIndex] = this.vectorSideLengths.get(intIndex);
    }
    return allSideLengths;
  }
  
  /**Get the number of items in the history. 
   * Must be named according to property syntax so that it can be 
   * use in an JSP-EL expression.
   * 
   * @return Number of items in history
   */
  public int getSize()
  {
    return this.vectorSideLengths.size();
  }
}
